==> am_mod_lbr_0_3.zip: am_mod_lbr_0_3/components/lbr/language/1/barnraiser_01/help/index.help.lang.php <==
<h1>Introducing the library</h1>
<p>
	Wiki-sets are like books made by many contributors over time. There are many wiki-sets here covering a vast plethora of information.<br />
</p>

<toc>Library help contents</toc>

<hr />

<h2>What is a wiki?</h2>
<p>
	'Wiki' is the Hawaiian term wiki wiki, meaning "quick" or "super-fast". A wiki enables documents to be written collectively in a simple markup language using a web browser. A single page in a wiki is referred to as a "wiki page", while the entire body of pages, which are usually highly interconnected via hyperlinks, is called "the wiki."<br />
</p>


<h2>Wiki structure</h2>
<p>
	The wiki contains a number of 'wiki'sets' (as a library contains a number of books). Each wiki-set (or book) contains a number of pages. Each page can be revised (or edited) to add more information. These are known as revisions. Nothing is deleted and editors can back out a revision if it is inaccurate.<br />
</p>

<p>
	Each wiki-set is maintained by an editor in chief. Working beside the editor in chief are a number of editors who write and maintain the pages. Other contributors can make changes to each page and add comments if the editors allow this.<br />
</p>



<a name="set"></a>
<h2>Wiki-sets</h2>
<p>
	A wiki-set (or book) contains a number of pages. Each wiki-set has a first page which we call the 'default page'.<br />
</p>

<h3>Creating a wiki-set</h3>
<p>
	here<br />
</p>

<h3>Inter linking pages</h3>
<p>
	here<br />
</p>


<h3>Creating a table of contents</h3>
<p>
	here<br />
</p>













<a name="page"></a>
<h3>Viewing your wiki page</h3>
A look at the page.tpl.php file


<a name="revisions"></a>
<h3>Viewing your wiki page revision</h3>
A look at the page.tpl.php file


<a name="edit"></a>
<h3>Creating and editting your wiki-set</h3>
<ul>
<li><b>title</b>: The title of the wiki-set. A short heading for the wiki-set (50 characters max).</li>
<li><b>synopsis</b>: A descrition of the wiki-set for inclusion in listings (250 characters max).</li>
</ul>

<h3>page constituents</h3>
<ul>
<li><b>title</b>: The title of the wiki page. A short heading for the wiki page (50 characters max).</li>
<li><b>synopsis</b>: A descrition of the wiki page for inclusion in listings (250 characters max).</li>
<li><b>page name</b>: A studly caps formatted name for use when interlinking wiki pages. Studly caps formatted text is made up of several words linked together with an uppercase character at the start of each word !LikeThis.</li>
</ul>

<h3>revision constituents</h3>
<ul>
<li><b>body</b>: The title of the wiki page revision. A short heading for the wiki page revision (50 characters max).</li>
<li><b>note</b>: A note against the wiki page revision for editors. Describe the change you have made to your revision (250 characters max).</li>
</ul>







<h3>participant status</h3>

	A person who is an editor in chief or an editor with permission to manage contributors can change the status of a contributor. There are four status types:


<ul>
<li><b>Pending</b>: A guest who wants to become a contributor in this wiki-set.</li>
<li><b>Active</b>: A contributor who can make a new revision of a page.</li>
<li><b>Hold</b>: A contributor who is temporarilly forbidden from adding a new revision.</li>
<li><b>Barred</b>: A person who has broken the wiki-set policy and has been exciled from the wiki editorial team.</li>
</ul>

<h3>roles</h3>
A person interacting with the wiki-set is given a role. There are four types of role:

<ul>
<li><b>Editor in chief</b>: This person is the maintainer of the wiki-set. They set permissions and assign editors.</li>
<li><b>Editor</b>: Editors can be assigned a editorial role by the Editor in chief. An editor writes and maintains the wiki-stes pages.</li>
<li><b>Contributor</b>: Any person who has joined this wiki-set.</li>
<li><b>Guest</b>: Someone who is looking at information in this wiki-set who has not joined it.</li>
</ul>

==> am_mod_lbr_0_5.zip: am_mod_lbr_0_5/components/lbr/language/1/barnraiser_01/help/index.help.lang.php <==
<h1>Introducing the library</h1>
<p>
	Wiki-sets are like books made by many contributors over time. There are many wiki-sets here covering a vast plethora of information.<br />
</p>

<toc>Library help contents</toc>

<hr />

<h2>What is a wiki?</h2>
<p>
	'Wiki' is the Hawaiian term wiki wiki, meaning "quick" or "super-fast". A wiki enables documents to be written collectively in a simple markup language using a web browser. A single page in a wiki is referred to as a "wiki page", while the entire body of pages, which are usually highly interconnected via hyperlinks, is called "the wiki."<br />
</p>


<h2>Wiki structure</h2>
<p>
	The wiki contains a number of 'wiki'sets' (as a library contains a number of books). Each wiki-set (or book) contains a number of pages. Each page can be revised (or edited) to add more information. These are known as revisions. Nothing is deleted and editors can back out a revision if it is inaccurate.<br />
</p>

<p>
	Each wiki-set is maintained by an editor in chief. Working beside the editor in chief are a number of editors who write and maintain the pages. Other contributors can make changes to each page and add comments if the editors allow this.<br />
</p>


<h2>Navigational overview</h2>
<p>
	Under the blog section is a sub-menu containing the following options:<br />
</p>

<ul>
	<li>overview - This page gives a summary of the latest wiki-sets, your wiki-sets and the latest revisions from your respected network.</li>
    <li>cloud - This pages gives you a view of wiki pages based on the metadata people have collected by tagging the pages.</li>
    <li>create - If you have permission you can create a wiki-set.</li>
    <li>search - Search and list wiki-sets and wiki pages.</li>
</ul>

<h3>Content area navigation</h3>
<p>
	The content area contains the main item together with a number of navigational
elements and icons.<br />
</p>


<h4>Navigational icons</h4>

<table cellspacing="0" cellpadding="6" border="0">
	<tr>
		<td valign="top">
			<img src="SYS_KEYWORD_TEMPLATE_PATHimg/mark.png" alt="bookmark icon"
border="0" />
		</td>
		<td valign="top">
			You can add this item to your bookmarked items list for later
reading.
		</td>
	</tr>
	<tr>
		<td valign="top">
			<img src="SYS_KEYWORD_TEMPLATE_PATHimg/unmark.png" alt="remove
bookmark icon" border="0" />
		</td>
		<td valign="top">
			You have this item in your bookmarked items list. Press to remove
the item from your list.
		</td>
	</tr>
	<tr>
		<td valign="top">
			<img src="SYS_KEYWORD_TEMPLATE_PATHimg/track.png" alt="track icon"
border="0" />
		</td>
		<td valign="top">
			You can add this item to your bookmarked items list for later
reading and track it, meaning that you will receive an email when a comment is
added against the item.
		</td>
	</tr>
	<tr>
		<td valign="top">
			<img src="SYS_KEYWORD_TEMPLATE_PATHimg/recommend.png" alt="recommend
icon" border="0" />
		</td>
		<td valign="top">
			You can add this item to your recommended items list or your
respected network.
		</td>
	</tr>
	<tr>
		<td valign="top">
			<img src="SYS_KEYWORD_TEMPLATE_PATHimg/unrecommend.png" alt="remove
recommendation icon" border="0" />
		</td>
		<td valign="top">
			You have this item in your recommended items list. Press to remove
the item from your list.
		</td>
	</tr>
	<tr>
		<td valign="top" nowrap="nowrap">
			<img src="SYS_KEYWORD_TEMPLATE_PATHimg/thumb_up.png" alt="positive
rating icon" border="0" />
			&nbsp;
			<img src="SYS_KEYWORD_TEMPLATE_PATHimg/thumb_down.png" alt="negative
rating  icon" border="0" />
		</td>
		<td valign="top">
			You can rate an item by awarding it a positive (thumbs up) or
negative (thumbs down) rating.
		</td>
	</tr>
</table>



<a name="set"></a>
<h2>Wiki-sets</h2>
<p>
	A wiki-set (or book) contains a number of pages. Each wiki-set has a first page which we call the 'default page'.<br />
</p>

<h3>Creating a wiki-set</h3>
<p>
	here<br />
</p>

<h3>Inter linking pages</h3>
<p>
	here<br />
</p>


<h3>Creating a table of contents</h3>
<p>
	here<br />
</p>













<a name="page"></a>
<h3>Viewing your wiki page</h3>
A look at the page.tpl.php file


<a name="revisions"></a>
<h3>Viewing your wiki page revision</h3>
A look at the page.tpl.php file


<a name="edit"></a>
<h3>Creating and editting your wiki-set</h3>
<ul>
<li><b>title</b>: The title of the wiki-set. A short heading for the wiki-set (50 characters max).</li>
<li><b>synopsis</b>: A descrition of the wiki-set for inclusion in listings (250 characters max).</li>
</ul>

<h3>page constituents</h3>
<ul>
<li><b>title</b>: The title of the wiki page. A short heading for the wiki page (50 characters max).</li>
<li><b>synopsis</b>: A descrition of the wiki page for inclusion in listings (250 characters max).</li>
<li><b>page name</b>: A studly caps formatted name for use when interlinking wiki pages. Studly caps formatted text is made up of several words linked together with an uppercase character at the start of each word !LikeThis.</li>
</ul>

<h3>revision constituents</h3>
<ul>
<li><b>body</b>: The title of the wiki page revision. A short heading for the wiki page revision (50 characters max).</li>
<li><b>note</b>: A note against the wiki page revision for editors. Describe the change you have made to your revision (250 characters max).</li>
</ul>







<h3>participant status</h3>

	A person who is an editor in chief or an editor with permission to manage contributors can change the status of a contributor. There are four status types:


<ul>
<li><b>Pending</b>: A guest who wants to become a contributor in this wiki-set.</li>
<li><b>Active</b>: A contributor who can make a new revision of a page.</li>
<li><b>Hold</b>: A contributor who is temporarilly forbidden from adding a new revision.</li>
<li><b>Barred</b>: A person who has broken the wiki-set policy and has been exciled from the wiki editorial team.</li>
</ul>

<h3>roles</h3>
A person interacting with the wiki-set is given a role. There are four types of role:

<ul>
<li><b>Editor in chief</b>: This person is the maintainer of the wiki-set. They set permissions and assign editors.</li>
<li><b>Editor</b>: Editors can be assigned a editorial role by the Editor in chief. An editor writes and maintains the wiki-stes pages.</li>
<li><b>Contributor</b>: Any person who has joined this wiki-set.</li>
<li><b>Guest</b>: Someone who is looking at information in this wiki-set who has not joined it.</li>
</ul>
